pub struct MavEnum {
pub name: String,
pub description: Option<String>,
pub entries: Vec<MavEnumEntry>,
pub primitive: Option<String>,
pub bitmask: bool,
pub deprecated: Option<MavDeprecation>,
}Fields
name: Stringdescription: Option<String>entries: Vec<MavEnumEntry>primitive: Option<String>If contains Some, the string represents the primitive type (size) for bitflags. If no fields use this enum, the bitmask is true, but primitive is None. In this case regular enum is generated as primitive is unknown.
bitmask: booldeprecated: Option<MavDeprecation>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for MavEnum
impl<'de> Deserialize<'de> for MavEnum
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for MavEnum